@@ -9,7 +9,7 @@ import re
 import sys
 import time
 from datetime import datetime
-from types import TracebackType
+from types import FrameType, TracebackType
 from typing import Any
 
 import pytest
@@ -34,8 +34,6 @@ class PytestAdaptavist:
     :param config: The pytest config object
     """
 
-    FAILED_ASSUMPTIONS: list[Assumption] = []
-
     def __init__(self, config: Config):
         self.item_status_info: dict[str, Any] = {}
         self.test_refresh_info: dict[str, Any] = {}
@@ -43,6 +41,7 @@ class PytestAdaptavist:
         self.report: dict[str, Any] = {}
         self.project_key: str | None = None
         self.test_run_keys: list[str] = []
+        self.failed_assumptions: list[Assumption] = []
         self.failed_assumptions_step: list[Assumption] = []
         self.reporter: TerminalReporter = config.pluginmanager.getplugin("terminalreporter")
         self.build_url = ""
@@ -122,9 +121,9 @@ class PytestAdaptavist:
     @pytest.hookimpl(tryfirst=True)
     def pytest_runtest_setup(self, item: pytest.Item):
         """This is called before calling the test item. Used to skip test items dynamically (e.g. triggered by some other item or control function)."""
-        # TODO Make this more generalistic
         # Needed to ensure that a class decorator is preferred over a function decorator.
-        if item.cls and getattr(item.cls, "pytestmark", False) and all((mark.name != "block" for mark in item.cls.pytestmark)):  # type: ignore
+        if (item.cls and getattr(item.cls, "pytestmark", False)  # type: ignore
+                and all((mark.name != "block" for mark in item.cls.pytestmark)) and not item.get_closest_marker("block")):  # type: ignore
             return
         if skip_status := (item.get_closest_marker("block")):
             fullname = get_item_nodeid(item)
@@ -148,25 +147,29 @@ class PytestAdaptavist:
             if stack_entry.function == "check" and stack_entry.filename.endswith("metablock.py"):
                 test_call_index = index + 1
                 break
-        (frame, _, _, _, contextlist) = inspect.stack()[test_call_index][0:5]
+        (frame, _, _, _, contextlist) = stack[test_call_index][:5]
         local_locals = [f"{name:10s} = {saferepr(val)}" for name, val in frame.f_locals.items()]
         self.failed_assumptions_step.append([])
-        self.FAILED_ASSUMPTIONS.append(Assumption((contextlist or [""])[0].lstrip(), frame, local_locals))
+        self.failed_assumptions.append(AdaptavistAssumption((contextlist or [""])[0].lstrip(), frame, local_locals))
 
     @pytest.hookimpl()
     def pytest_assume_summary_report(self, failed_assumptions: list[Assumption]) -> str:
         """Manipulate the summary that prints at the end."""
-        for failed_assumption in zip(failed_assumptions, self.FAILED_ASSUMPTIONS):
-            frame, filename, lineno, _, codecontext = inspect.getouterframes(failed_assumption[0].tb.tb_frame)[2][0:5]
-            msg = frame.f_locals.get("message_on_fail")
-            context = msg or ((codecontext or [""])[0]).lstrip()
-            local_entry = f"{os.path.relpath(filename)}:{lineno}: AssumptionFailure\n\t{context}"
+        for failed_assumption in zip(failed_assumptions, self.failed_assumptions):
+            filename = inspect.getouterframes(failed_assumption[0].tb.tb_frame)[3][1]
+            frame = inspect.getouterframes(failed_assumption[0].tb.tb_frame)[2][0]
+            msg = frame.f_locals.get("message_on_fail", "")
+            context = (msg or failed_assumption[1].entry.strip()) + "\n"
+            local_entry = f"{os.path.relpath(filename)}:{failed_assumption[1].line_no}: AssumptionFailure\n\t{context}"
             failed_assumption[0].locals = failed_assumption[1].locals
-            failed_assumption[0].entry = local_entry
+            failed_assumption[1].entry = local_entry
 
-        return "".join(failed_assumption.longrepr() for failed_assumption in self.FAILED_ASSUMPTIONS) \
-            if getattr(pytest, "_showlocals") \
-            else "".join(failed_assumption.repr() for failed_assumption in self.FAILED_ASSUMPTIONS)
+        report = "\n".join(failed_assumption.longrepr() + "\n\n" for failed_assumption in self.failed_assumptions)\
+            if not getattr(pytest, "_showlocals") \
+            else "\n".join(failed_assumption.repr() for failed_assumption in self.failed_assumptions)
+
+        self.failed_assumptions = []
+        return report
 
     def create_report(self,
                       test_case_key: str,
@@ -273,7 +276,7 @@ class PytestAdaptavist:
             # find the right position to insert comments of this test execution (in case of parametrized or repeated test methods)
             index = test_result.get("comment", "").find("---------------------------------------- ")
 
-            if comments in test_result.get("comment", ""):
+            if comment and comments in test_result.get("comment", ""):
                 comment = ""
             else:
                 comment = (test_result.get("comment", "") + comments) if index < 0 else \
@@ -404,8 +407,7 @@ class PytestAdaptavist:
 
         if call.when not in ("call", "setup") or (item.cls and getattr(item.cls, "pytestmark", False)  # type: ignore
                                                   and all((mark.name != "block" for mark in item.cls.pytestmark))  # type: ignore
-                                                  and all((mark.name == "skipif"  # type: ignore
-                                                           and mark.args[0] is True for mark in item.cls.pytestmark))):  # type: ignore  # yapf: disable
+                                                  and any((mark.args[0] is True for mark in item.cls.pytestmark if mark.name == "skipif"))):  # type: ignore
             return
         if item.get_closest_marker("block") or (call.excinfo and call.excinfo.type is pytest.block.Exception):  # type: ignore
             report.blocked = True  # type: ignore
@@ -712,6 +714,14 @@ class PytestAdaptavist:
                 item.add_marker(pytest.mark.skip)
 
 
+class AdaptavistAssumption(Assumption):
+    """Inherited assumption object extended with a line number attribute."""
+
+    def __init__(self, entry: str, tb: FrameType, locals: list[str] | None = None):  # pylint: disable=redefined-builtin
+        self.line_no = tb.f_lineno
+        super().__init__(entry, tb, locals)
+
+
 def is_unexpected_exception(exc_type: Exception) -> bool:
     """Check if exception type is unexpected (any exception except AssertionError, pytest.block.Exception, pytest.skip.Exception)."""
     if exc_type and (isinstance(exc_type, (Exception, BaseException)) or issubclass(exc_type, (Exception, BaseException))):
