@@ -1,6 +1,7 @@
 """Test connection between pytest and Adaptavist."""
 
 import getpass
+import re
 from io import BytesIO
 from unittest.mock import patch
 
@@ -159,6 +160,39 @@ class TestPytestAdaptavistUnit:
         assert etrs.call_args.kwargs["test_case_key"] == "TEST-T125"
         assert "skipped as requested" in etrs.call_args.kwargs["comment"]
 
+    def test_xfail(self, pytester: pytest.Pytester):
+        """Test that xfail is handled properly."""
+        pytester.makepyfile("""
+            import pytest
+
+            @pytest.mark.xfail
+            def test_T125(meta_block):
+                assert False
+        """)
+        outcome = pytester.runpytest().parseoutcomes()
+        assert outcome["xfailed"] == 1
+
+    def test_correct_stacktrace(self, pytester: pytest.Pytester):
+        """Test that the correct stack trace is printed."""
+        pytester.makepyfile("""
+                def test_a(meta_block):
+                    with meta_block(1) as mb_1:
+                        mb_1.check(not True)
+
+                def test_b(meta_block):
+                    with meta_block(1) as mb_1:
+                        mb_1.check(False)
+                    with meta_block(2) as mb_2:
+                        mb_2.check(not not False)
+                            """)
+        outcome = pytester.runpytest()
+        regex = re.findall("not True", str(outcome.outlines).replace('\'', "").replace("[", "").replace("]", ""))
+        assert len(regex) == 1
+        regex = re.findall("\\(False", str(outcome.outlines).replace('\'', "").replace("[", "").replace("]", ""))
+        assert len(regex) == 1
+        regex = re.findall("not not False", str(outcome.outlines).replace('\'', "").replace("[", "").replace("]", ""))
+        assert len(regex) == 1
+
 
 @pytest.mark.system
 @pytest.mark.skipif(not system_test_preconditions(), reason="Preconditions for system tests not met. Please see README.md")
@@ -228,7 +262,7 @@ class TestPytestAdaptavistSystem:
         test_run_key, test_name = get_test_values(report)
         test_result = adaptavist.get_test_result(test_run_key, test_name)
         assert test_result["status"] == "Blocked"
-        assert test_result["comment"] == "Testing block<br>step 2 blocked"
+        assert test_result["comment"] == "Testing block<br>Step 2 blocked"
         assert test_result["scriptResults"][0]["status"] == "Pass"
         assert test_result["scriptResults"][1]["status"] == "Blocked"
 
@@ -348,7 +382,7 @@ class TestPytestAdaptavistSystem:
         test_result = adaptavist.get_test_result(test_run_key, test_name)
         assert len(attachments) == 0
         assert test_result["status"] == "Blocked"
-        assert test_result["comment"] == "step 1 blocked"
+        assert test_result["comment"] == "Step 1 blocked"
         assert test_result["scriptResults"][0]["status"] == "Blocked"
         assert test_result["scriptResults"][1]["status"] == "Pass"
 
@@ -373,7 +407,7 @@ class TestPytestAdaptavistSystem:
         test_result = adaptavist.get_test_result(test_run_key, test_name)
         assert len(attachments) == 0
         assert test_result["status"] == "Fail"
-        assert test_result["comment"] == "step 1 failed:"
+        assert test_result["comment"] == "Step 1 failed:"
         assert test_result["scriptResults"][0]["status"] == "Fail"
         assert test_result["scriptResults"][1]["status"] == "Not Executed"
 
@@ -483,6 +517,10 @@ class TestPytestAdaptavistSystem:
         assert test_result == {}
 
     def test_T16(self, pytester: pytest.Pytester, adaptavist: Adaptavist, test_run: str):
+        """
+        Test meta_data
+        Expect that T16 is failed. Upload file with correct filename and size.
+        """
         pytester.maketxtfile(first_file="foo")
         pytester.maketxtfile(second_file="bar")
         pytester.makepyfile("""
